API
===

.. automodule:: resonance.system
   :members:

.. automodule:: resonance.linear_systems
   :members:

.. automodule:: resonance.nonlinear_systems
   :members:

.. automodule:: resonance.functions
   :members:
